@@ -49,6 +49,7 @@
 
 package com.openexchange.user.copy.internal.folder;
 
+import static com.openexchange.java.Autoboxing.I;
 import static com.openexchange.java.Autoboxing.i;
 import java.sql.Connection;
 import java.sql.PreparedStatement;
@@ -175,7 +176,7 @@ public class FolderCopyTask implements CopyUserTaskService {
             try {
                 final int id = folder.getObjectID();
                 if (!ignoreFolder(id)) {
-                    originFolders.put(id, folder.clone());
+                    originFolders.put(I(id), folder.clone());
                 }
             } catch (final CloneNotSupportedException e) {
                 throw UserCopyExceptionCodes.UNKNOWN_PROBLEM.create(e);
@@ -238,7 +239,7 @@ public class FolderCopyTask implements CopyUserTaskService {
 
             while (rs.next()) {
                 final FolderObject folder = buildFolderFromResultSet(rs);
-                folderMap.put(folder.getObjectID(), new FolderEqualsWrapper(folder, "orig"));
+                folderMap.put(I(folder.getObjectID()), new FolderEqualsWrapper(folder, "orig"));
             }
         } catch (final SQLException e) {
             throw UserCopyExceptionCodes.SQL_PROBLEM.create(e);
@@ -280,10 +281,10 @@ public class FolderCopyTask implements CopyUserTaskService {
 
         final SortedMap<Integer, FolderEqualsWrapper> extendedMap = new TreeMap<Integer, FolderEqualsWrapper>();
         extendedMap.putAll(folderMap);
-        extendedMap.put(privateFolder.getObjectID(), privateFolder);
-        extendedMap.put(systemInfostoreFolder.getObjectID(), systemInfostoreFolder);
-        extendedMap.put(userInfostoreFolder.getObjectID(), userInfostoreFolder);
-        extendedMap.put(publicInfostoreFolder.getObjectID(), publicInfostoreFolder);
+        extendedMap.put(I(privateFolder.getObjectID()), privateFolder);
+        extendedMap.put(I(systemInfostoreFolder.getObjectID()), systemInfostoreFolder);
+        extendedMap.put(I(userInfostoreFolder.getObjectID()), userInfostoreFolder);
+        extendedMap.put(I(publicInfostoreFolder.getObjectID()), publicInfostoreFolder);
 
         /*
          * A recursion is used here to be sure that the folder tree always contains a folders parent before the folder is added.
@@ -301,9 +302,9 @@ public class FolderCopyTask implements CopyUserTaskService {
     private void addFoldersRecursive(final SortedMap<Integer, FolderEqualsWrapper> folderMap, final Tree<FolderEqualsWrapper> folderTree, final FolderEqualsWrapper folder) throws OXException {
         final int folderId = folder.getObjectID();
         final int parentFolderId = folder.getParentFolderID();
-        final FolderEqualsWrapper parent = folderMap.get(parentFolderId);
+        final FolderEqualsWrapper parent = folderMap.get(I(parentFolderId));
         if (parentFolderId != 0 && parent == null) {
-            LOG.warn(String.format("A private folder (%1$s) without existing parent (%2$s) was found. The folder will be ignored!", folderId, folder.getParentFolderID()));
+            LOG.warn(String.format("A private folder (%1$s) without existing parent (%2$s) was found. The folder will be ignored!", I(folderId), I(folder.getParentFolderID())));
             return;
         }
 
@@ -378,7 +379,7 @@ public class FolderCopyTask implements CopyUserTaskService {
             int newId = origId;
             if (!ignoreFolder(origId)) {
                 newId = IDGenerator.getId(cid, com.openexchange.groupware.Types.FOLDER, con);
-                idMapping.put(origId, newId);
+                idMapping.put(I(origId), I(newId));
             }
 
             final FolderEqualsWrapper rootClone = root.clone();
@@ -496,13 +497,13 @@ public class FolderCopyTask implements CopyUserTaskService {
                 Integer folderId = null;
                 Integer parentId = null;
                 try {
-                    Integer tmp = Integer.parseInt(folderIdStr);
+                    Integer tmp = Integer.valueOf(folderIdStr);
                     final Integer newFolderId = idMapping.get(tmp);
                     if (newFolderId != null) {
                         folderId = newFolderId;
                     }
 
-                    tmp = Integer.parseInt(parentIdStr);
+                    tmp = Integer.valueOf(parentIdStr);
                     final Integer newParentId = idMapping.get(tmp);
                     if (newParentId != null) {
                         parentId = newParentId;
