@@ -69,11 +69,6 @@ public class UserCopyServiceActivator extends HousekeepingActivator {
         openTrackers();
     }
 
-    @Override
-    public void stopBundle() throws Exception {
-        closeTrackers();
-    }
-
     @Override
     protected Class<?>[] getNeededServices() {
         // Nothing to do
